==> ejc-zjkjcost-api-3.0.0-20230419.031408-137-sources.jar: com/ejianc/business/zjkjcost/optimization/vo/OptimizationRewardVO.java <==
package com.ejianc.business.zjkjcost.optimization.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.math.BigDecimal;


/**
 * 项目优化-项目优化奖励申请
 *
 * @author generator
 *
 */
@ApiModel("项目优化-项目优化奖励申请")
public class OptimizationRewardVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    @ApiModelProperty("单据编号")
    private String billCode;
    @ApiModelProperty("单据状态（审批必须字段）")
    private Integer billState;
    @ApiModelProperty("备注")
    private String memo;
    @ApiModelProperty("项目ID")
    private Long projectId;
    @ApiModelProperty("项目名称")
    private String projectName;
    @ApiModelProperty("项目编号")
    private String projectCode;
    @ApiModelProperty("组织")
    private Long orgId;
    @ApiModelProperty("组织名称")
    private String orgName;
    @ApiModelProperty("项目部编码")
    private String orgCode;
    @ApiModelProperty("父级组织")
    private Long parentOrgId;
    @ApiModelProperty("父级组织名称")
    private String parentOrgName;
    @ApiModelProperty("项目部上级组织编码")
    private String parentOrgCode;
    @ApiModelProperty("合同id")
    private Long contractId;
    @ApiModelProperty("合同名称")
    private String contractName;
    @ApiModelProperty("合同编号")
    private String contractCode;
    @ApiModelProperty("项目优化立项申报id")
    private Long topicId;
    @ApiModelProperty("项目优化立项申报名称")
    private String topicName;
    @ApiModelProperty("项目优化立项申报编号")
    private String topicCode;
    @ApiModelProperty("经办人")
    private Long employeeId;
    @ApiModelProperty("经办人名称")
    private String employeeName;
    @ApiModelProperty("经办部门")
    private Long departmentId;
    @ApiModelProperty("经办部门名称")
    private String departmentName;
    @ApiModelProperty("实现净效益额")
    private BigDecimal benefitMny;
    @ApiModelProperty("按项目优化奖标准应计取奖励金额")
    private BigDecimal rewardMny;
    @ApiModelProperty("实现净效益额详情")
    private String benefitExplain;
    @ApiModelProperty("按项目优化奖标准应计取奖励金额详情")
    private String rewardExplain;
    @ApiModelProperty("本立项已实施完毕，并经发包人签字确认，签字状态，0-未签字,1-已签字")
    private Integer signStatus;
    @ApiModelProperty("评审意见")
    private String reviewOpinion;
    @ApiModelProperty("所属单位商务管理部实现净效益额")
    private BigDecimal departmentBenefitMny;
    @ApiModelProperty("所属单位商务管理部按项目优化奖标准应计取奖励金额")
    private BigDecimal departmentRewardMny;
    @ApiModelProperty("所属单位商务管理部实现净效益额详情")
    private String departmentBenefitExplain;
    @ApiModelProperty("所属单位商务管理部按项目优化奖标准应计取奖励金额详情")
    private String departmentRewardExplain;
    @ApiModelProperty("所属单位分管领导计取奖励金额")
    private BigDecimal leaderRewardMny;
    @ApiModelProperty("所属单位总经理兑现金额")
    private BigDecimal managerCashMny;
    @ApiModelProperty("所属单位董事长兑现金额")
    private BigDecimal chairmanCashMny;
    @ApiModelProperty("立项类型ID")
    private Long topicTypeId;
    @ApiModelProperty("立项类型名称")
    private String topicTypeName;

    public Long getTopicTypeId() {
        return topicTypeId;
    }

    public void setTopicTypeId(Long topicTypeId) {
        this.topicTypeId = topicTypeId;
    }

    public String getTopicTypeName() {
        return topicTypeName;
    }

    public void setTopicTypeName(String topicTypeName) {
        this.topicTypeName = topicTypeName;
    }

    private String billStateName;

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }

    /**
     * 单据编号
     */
    public String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    /**
     * 项目ID
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public Long getProjectId() {
        return projectId;
    }

    /**
     * 项目ID
     */
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    /**
     * 项目编号
     */
    public String getProjectCode() {
        return projectCode;
    }

    /**
     * 项目编号
     */
    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    /**
     * 组织
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部编码
     */
    public String getOrgCode() {
        return orgCode;
    }

    /**
     * 项目部编码
     */
    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    /**
     * 父级组织
     */
    public Long getParentOrgId() {
        return parentOrgId;
    }

    /**
     * 父级组织
     */
    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    /**
     * 父级组织名称
     */
    public String getParentOrgName() {
        return parentOrgName;
    }

    /**
     * 父级组织名称
     */
    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    /**
     * 项目部上级组织编码
     */
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    /**
     * 项目部上级组织编码
     */
    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    /**
     * 合同id
     */
    @ReferSerialTransfer(referCode = "ejc-zjkj-incontract")
    public Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    @ReferDeserialTransfer
    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    /**
     * 合同编号
     */
    public String getContractCode() {
        return contractCode;
    }

    /**
     * 合同编号
     */
    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }
    /**
     * 项目优化立项申报id
     */
    @ReferSerialTransfer(referCode="refOptimizationTopic")
    public Long getTopicId() {
        return topicId;
    }

    /**
     * 项目优化立项申报id
     */
    @ReferDeserialTransfer
    public void setTopicId(Long topicId) {
        this.topicId = topicId;
    }
    /**
     * 项目优化立项申报名称
     */
    public String getTopicName() {
        return topicName;
    }

    /**
     * 项目优化立项申报名称
     */
    public void setTopicName(String topicName) {
        this.topicName = topicName;
    }
    /**
     * 项目优化立项申报编号
     */
    public String getTopicCode() {
        return topicCode;
    }

    /**
     * 项目优化立项申报编号
     */
    public void setTopicCode(String topicCode) {
        this.topicCode = topicCode;
    }
    /**
     * 经办人
     */
    @ReferSerialTransfer(referCode="idm-employee")
    public Long getEmployeeId() {
        return employeeId;
    }

    /**
     * 经办人
     */
    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    /**
     * 经办人名称
     */
    public String getEmployeeName() {
        return employeeName;
    }

    /**
     * 经办人名称
     */
    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    /**
     * 经办部门
     */
    @ReferSerialTransfer(referCode="idm-dept")
    public Long getDepartmentId() {
        return departmentId;
    }

    /**
     * 经办部门
     */
    @ReferDeserialTransfer
    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    /**
     * 经办部门名称
     */
    public String getDepartmentName() {
        return departmentName;
    }

    /**
     * 经办部门名称
     */
    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    /**
     * 实现净效益额
     */
    public BigDecimal getBenefitMny() {
        return benefitMny;
    }

    /**
     * 实现净效益额
     */
    public void setBenefitMny(BigDecimal benefitMny) {
        this.benefitMny = benefitMny;
    }
    /**
     * 按项目优化奖标准应计取奖励金额
     */
    public BigDecimal getRewardMny() {
        return rewardMny;
    }

    /**
     * 按项目优化奖标准应计取奖励金额
     */
    public void setRewardMny(BigDecimal rewardMny) {
        this.rewardMny = rewardMny;
    }
    /**
     * 实现净效益额详情
     */
    public String getBenefitExplain() {
        return benefitExplain;
    }

    /**
     * 实现净效益额详情
     */
    public void setBenefitExplain(String benefitExplain) {
        this.benefitExplain = benefitExplain;
    }
    /**
     * 按项目优化奖标准应计取奖励金额详情
     */
    public String getRewardExplain() {
        return rewardExplain;
    }

    /**
     * 按项目优化奖标准应计取奖励金额详情
     */
    public void setRewardExplain(String rewardExplain) {
        this.rewardExplain = rewardExplain;
    }
    /**
     * 本立项已实施完毕，并经发包人签字确认，签字状态，0-未签字,1-已签字
     */
    public Integer getSignStatus() {
        return signStatus;
    }

    /**
     * 本立项已实施完毕，并经发包人签字确认，签字状态，0-未签字,1-已签字
     */
    public void setSignStatus(Integer signStatus) {
        this.signStatus = signStatus;
    }
    /**
     * 评审意见
     */
    public String getReviewOpinion() {
        return reviewOpinion;
    }

    /**
     * 评审意见
     */
    public void setReviewOpinion(String reviewOpinion) {
        this.reviewOpinion = reviewOpinion;
    }
    /**
     * 所属单位商务管理部实现净效益额
     */
    public BigDecimal getDepartmentBenefitMny() {
        return departmentBenefitMny;
    }

    /**
     * 所属单位商务管理部实现净效益额
     */
    public void setDepartmentBenefitMny(BigDecimal departmentBenefitMny) {
        this.departmentBenefitMny = departmentBenefitMny;
    }
    /**
     * 所属单位商务管理部按项目优化奖标准应计取奖励金额
     */
    public BigDecimal getDepartmentRewardMny() {
        return departmentRewardMny;
    }

    /**
     * 所属单位商务管理部按项目优化奖标准应计取奖励金额
     */
    public void setDepartmentRewardMny(BigDecimal departmentRewardMny) {
        this.departmentRewardMny = departmentRewardMny;
    }
    /**
     * 所属单位商务管理部实现净效益额详情
     */
    public String getDepartmentBenefitExplain() {
        return departmentBenefitExplain;
    }

    /**
     * 所属单位商务管理部实现净效益额详情
     */
    public void setDepartmentBenefitExplain(String departmentBenefitExplain) {
        this.departmentBenefitExplain = departmentBenefitExplain;
    }
    /**
     * 所属单位商务管理部按项目优化奖标准应计取奖励金额详情
     */
    public String getDepartmentRewardExplain() {
        return departmentRewardExplain;
    }

    /**
     * 所属单位商务管理部按项目优化奖标准应计取奖励金额详情
     */
    public void setDepartmentRewardExplain(String departmentRewardExplain) {
        this.departmentRewardExplain = departmentRewardExplain;
    }
    /**
     * 所属单位分管领导计取奖励金额
     */
    public BigDecimal getLeaderRewardMny() {
        return leaderRewardMny;
    }

    /**
     * 所属单位分管领导计取奖励金额
     */
    public void setLeaderRewardMny(BigDecimal leaderRewardMny) {
        this.leaderRewardMny = leaderRewardMny;
    }
    /**
     * 所属单位总经理兑现金额
     */
    public BigDecimal getManagerCashMny() {
        return managerCashMny;
    }

    /**
     * 所属单位总经理兑现金额
     */
    public void setManagerCashMny(BigDecimal managerCashMny) {
        this.managerCashMny = managerCashMny;
    }
    /**
     * 所属单位董事长兑现金额
     */
    public BigDecimal getChairmanCashMny() {
        return chairmanCashMny;
    }

    /**
     * 所属单位董事长兑现金额
     */
    public void setChairmanCashMny(BigDecimal chairmanCashMny) {
        this.chairmanCashMny = chairmanCashMny;
    }

}

==> ejc-zjkjcost-api-3.0.0-20230420.113908-142-sources.jar: com/ejianc/business/zjkjcost/optimization/vo/OptimizationRewardVO.java <==
package com.ejianc.business.zjkjcost.optimization.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.math.BigDecimal;


/**
 * 项目优化-项目优化奖励申请
 *
 * @author generator
 *
 */
@ApiModel("项目优化-项目优化奖励申请")
public class OptimizationRewardVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    @ApiModelProperty("单据编号")
    private String billCode;
    @ApiModelProperty("单据状态（审批必须字段）")
    private Integer billState;
    @ApiModelProperty("备注")
    private String memo;
    @ApiModelProperty("项目ID")
    private Long projectId;
    @ApiModelProperty("项目名称")
    private String projectName;
    @ApiModelProperty("项目编号")
    private String projectCode;
    @ApiModelProperty("组织")
    private Long orgId;
    @ApiModelProperty("组织名称")
    private String orgName;
    @ApiModelProperty("项目部编码")
    private String orgCode;
    @ApiModelProperty("父级组织")
    private Long parentOrgId;
    @ApiModelProperty("父级组织名称")
    private String parentOrgName;
    @ApiModelProperty("项目部上级组织编码")
    private String parentOrgCode;
    @ApiModelProperty("合同id")
    private Long contractId;
    @ApiModelProperty("合同名称")
    private String contractName;
    @ApiModelProperty("合同编号")
    private String contractCode;
    @ApiModelProperty("项目优化立项申报id")
    private Long topicId;
    @ApiModelProperty("项目优化立项申报名称")
    private String topicName;
    @ApiModelProperty("项目优化立项申报编号")
    private String topicCode;
    @ApiModelProperty("经办人")
    private Long employeeId;
    @ApiModelProperty("经办人名称")
    private String employeeName;
    @ApiModelProperty("经办部门")
    private Long departmentId;
    @ApiModelProperty("经办部门名称")
    private String departmentName;
    @ApiModelProperty("实现净效益额")
    private BigDecimal benefitMny;
    @ApiModelProperty("按项目优化奖标准应计取奖励金额")
    private BigDecimal rewardMny;
    @ApiModelProperty("实现净效益额详情")
    private String benefitExplain;
    @ApiModelProperty("按项目优化奖标准应计取奖励金额详情")
    private String rewardExplain;
    @ApiModelProperty("本立项已实施完毕，并经发包人签字确认，签字状态，0-未签字,1-已签字")
    private Integer signStatus;
    @ApiModelProperty("评审意见")
    private String reviewOpinion;
    @ApiModelProperty("所属单位商务管理部实现净效益额")
    private BigDecimal departmentBenefitMny;
    @ApiModelProperty("所属单位商务管理部按项目优化奖标准应计取奖励金额")
    private BigDecimal departmentRewardMny;
    @ApiModelProperty("所属单位商务管理部实现净效益额详情")
    private String departmentBenefitExplain;
    @ApiModelProperty("所属单位商务管理部按项目优化奖标准应计取奖励金额详情")
    private String departmentRewardExplain;
    @ApiModelProperty("所属单位分管领导计取奖励金额")
    private BigDecimal leaderRewardMny;
    @ApiModelProperty("所属单位总经理兑现金额")
    private BigDecimal managerCashMny;
    @ApiModelProperty("所属单位董事长兑现金额")
    private BigDecimal chairmanCashMny;
    @ApiModelProperty("立项类型ID")
    private Long topicTypeId;
    @ApiModelProperty("立项类型名称")
    private String topicTypeName;
    private BigDecimal applyMny; // 申请金额

    private Long calcId; // 项目优化立项计算id
    private String calcName; // 项目优化立项计算名称
    private String calcCode; // 项目优化立项计算编号

    public Long getCalcId() {
        return calcId;
    }

    public void setCalcId(Long calcId) {
        this.calcId = calcId;
    }

    public String getCalcName() {
        return calcName;
    }

    public void setCalcName(String calcName) {
        this.calcName = calcName;
    }

    public String getCalcCode() {
        return calcCode;
    }

    public void setCalcCode(String calcCode) {
        this.calcCode = calcCode;
    }

    public Long getTopicTypeId() {
        return topicTypeId;
    }

    public void setTopicTypeId(Long topicTypeId) {
        this.topicTypeId = topicTypeId;
    }

    public String getTopicTypeName() {
        return topicTypeName;
    }

    public void setTopicTypeName(String topicTypeName) {
        this.topicTypeName = topicTypeName;
    }

    private String billStateName;

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }

    /**
     * 单据编号
     */
    public String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    /**
     * 项目ID
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public Long getProjectId() {
        return projectId;
    }

    /**
     * 项目ID
     */
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    /**
     * 项目编号
     */
    public String getProjectCode() {
        return projectCode;
    }

    /**
     * 项目编号
     */
    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    /**
     * 组织
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部编码
     */
    public String getOrgCode() {
        return orgCode;
    }

    /**
     * 项目部编码
     */
    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    /**
     * 父级组织
     */
    public Long getParentOrgId() {
        return parentOrgId;
    }

    /**
     * 父级组织
     */
    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    /**
     * 父级组织名称
     */
    public String getParentOrgName() {
        return parentOrgName;
    }

    /**
     * 父级组织名称
     */
    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    /**
     * 项目部上级组织编码
     */
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    /**
     * 项目部上级组织编码
     */
    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    /**
     * 合同id
     */
    @ReferSerialTransfer(referCode = "ejc-zjkj-incontract")
    public Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    @ReferDeserialTransfer
    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    /**
     * 合同编号
     */
    public String getContractCode() {
        return contractCode;
    }

    /**
     * 合同编号
     */
    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }
    /**
     * 项目优化立项申报id
     */
    @ReferSerialTransfer(referCode="refOptimizationTopic")
    public Long getTopicId() {
        return topicId;
    }

    /**
     * 项目优化立项申报id
     */
    @ReferDeserialTransfer
    public void setTopicId(Long topicId) {
        this.topicId = topicId;
    }
    /**
     * 项目优化立项申报名称
     */
    public String getTopicName() {
        return topicName;
    }

    /**
     * 项目优化立项申报名称
     */
    public void setTopicName(String topicName) {
        this.topicName = topicName;
    }
    /**
     * 项目优化立项申报编号
     */
    public String getTopicCode() {
        return topicCode;
    }

    /**
     * 项目优化立项申报编号
     */
    public void setTopicCode(String topicCode) {
        this.topicCode = topicCode;
    }
    /**
     * 经办人
     */
    @ReferSerialTransfer(referCode="idm-employee")
    public Long getEmployeeId() {
        return employeeId;
    }

    /**
     * 经办人
     */
    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    /**
     * 经办人名称
     */
    public String getEmployeeName() {
        return employeeName;
    }

    /**
     * 经办人名称
     */
    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    /**
     * 经办部门
     */
    @ReferSerialTransfer(referCode="idm-dept")
    public Long getDepartmentId() {
        return departmentId;
    }

    /**
     * 经办部门
     */
    @ReferDeserialTransfer
    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    /**
     * 经办部门名称
     */
    public String getDepartmentName() {
        return departmentName;
    }

    /**
     * 经办部门名称
     */
    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    /**
     * 实现净效益额
     */
    public BigDecimal getBenefitMny() {
        return benefitMny;
    }

    /**
     * 实现净效益额
     */
    public void setBenefitMny(BigDecimal benefitMny) {
        this.benefitMny = benefitMny;
    }
    /**
     * 按项目优化奖标准应计取奖励金额
     */
    public BigDecimal getRewardMny() {
        return rewardMny;
    }

    /**
     * 按项目优化奖标准应计取奖励金额
     */
    public void setRewardMny(BigDecimal rewardMny) {
        this.rewardMny = rewardMny;
    }
    /**
     * 实现净效益额详情
     */
    public String getBenefitExplain() {
        return benefitExplain;
    }

    /**
     * 实现净效益额详情
     */
    public void setBenefitExplain(String benefitExplain) {
        this.benefitExplain = benefitExplain;
    }
    /**
     * 按项目优化奖标准应计取奖励金额详情
     */
    public String getRewardExplain() {
        return rewardExplain;
    }

    /**
     * 按项目优化奖标准应计取奖励金额详情
     */
    public void setRewardExplain(String rewardExplain) {
        this.rewardExplain = rewardExplain;
    }
    /**
     * 本立项已实施完毕，并经发包人签字确认，签字状态，0-未签字,1-已签字
     */
    public Integer getSignStatus() {
        return signStatus;
    }

    /**
     * 本立项已实施完毕，并经发包人签字确认，签字状态，0-未签字,1-已签字
     */
    public void setSignStatus(Integer signStatus) {
        this.signStatus = signStatus;
    }
    /**
     * 评审意见
     */
    public String getReviewOpinion() {
        return reviewOpinion;
    }

    /**
     * 评审意见
     */
    public void setReviewOpinion(String reviewOpinion) {
        this.reviewOpinion = reviewOpinion;
    }
    /**
     * 所属单位商务管理部实现净效益额
     */
    public BigDecimal getDepartmentBenefitMny() {
        return departmentBenefitMny;
    }

    /**
     * 所属单位商务管理部实现净效益额
     */
    public void setDepartmentBenefitMny(BigDecimal departmentBenefitMny) {
        this.departmentBenefitMny = departmentBenefitMny;
    }
    /**
     * 所属单位商务管理部按项目优化奖标准应计取奖励金额
     */
    public BigDecimal getDepartmentRewardMny() {
        return departmentRewardMny;
    }

    /**
     * 所属单位商务管理部按项目优化奖标准应计取奖励金额
     */
    public void setDepartmentRewardMny(BigDecimal departmentRewardMny) {
        this.departmentRewardMny = departmentRewardMny;
    }
    /**
     * 所属单位商务管理部实现净效益额详情
     */
    public String getDepartmentBenefitExplain() {
        return departmentBenefitExplain;
    }

    /**
     * 所属单位商务管理部实现净效益额详情
     */
    public void setDepartmentBenefitExplain(String departmentBenefitExplain) {
        this.departmentBenefitExplain = departmentBenefitExplain;
    }
    /**
     * 所属单位商务管理部按项目优化奖标准应计取奖励金额详情
     */
    public String getDepartmentRewardExplain() {
        return departmentRewardExplain;
    }

    /**
     * 所属单位商务管理部按项目优化奖标准应计取奖励金额详情
     */
    public void setDepartmentRewardExplain(String departmentRewardExplain) {
        this.departmentRewardExplain = departmentRewardExplain;
    }
    /**
     * 所属单位分管领导计取奖励金额
     */
    public BigDecimal getLeaderRewardMny() {
        return leaderRewardMny;
    }

    /**
     * 所属单位分管领导计取奖励金额
     */
    public void setLeaderRewardMny(BigDecimal leaderRewardMny) {
        this.leaderRewardMny = leaderRewardMny;
    }
    /**
     * 所属单位总经理兑现金额
     */
    public BigDecimal getManagerCashMny() {
        return managerCashMny;
    }

    /**
     * 所属单位总经理兑现金额
     */
    public void setManagerCashMny(BigDecimal managerCashMny) {
        this.managerCashMny = managerCashMny;
    }
    /**
     * 所属单位董事长兑现金额
     */
    public BigDecimal getChairmanCashMny() {
        return chairmanCashMny;
    }

    /**
     * 所属单位董事长兑现金额
     */
    public void setChairmanCashMny(BigDecimal chairmanCashMny) {
        this.chairmanCashMny = chairmanCashMny;
    }

    public BigDecimal getApplyMny() {
        return applyMny;
    }

    public void setApplyMny(BigDecimal applyMny) {
        this.applyMny = applyMny;
    }
}
